@@ -1,13 +1,18 @@
 from .doctest_plugin import (
     pytest_addoption,
+    pytest_collect_file,
     pytest_configure,
     pytest_runtest_makereport,
     pytest_sessionfinish,
 )
 
+# Note that pluginsn need to be listed here in order for pytest to pick them up when
+# this package is installed.
+
 __all__ = [
     pytest_runtest_makereport,
     pytest_sessionfinish,
     pytest_addoption,
     pytest_configure,
+    pytest_collect_file,
 ]
